==> qmmp_1.1.10.orig.tar.bz2: qmmp-1.1.10/src/plugins/Input/vorbis/translations/vorbis_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR">
<context>
    <name>DecoderVorbisFactory</name>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="52"/>
        <source>Ogg Vorbis Plugin</source>
        <translation>Ogg Vorbis Eklentisi</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="55"/>
        <source>Ogg Vorbis Files</source>
        <translation>Ogg Vorbis Dosyaları</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="130"/>
        <source>About Ogg Vorbis Audio Plugin</source>
        <translation>Ogg Vorbis Ses Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="131"/>
        <source>Qmmp Ogg Vorbis Audio Plugin</source>
        <translation>Qmmp Ogg Vorbis Ses Eklentisi</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="132"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="133"/>
        <source>Source code based on mq3 project</source>
        <translation>Kaynak kodu mq3 projesi temellidir</translation>
    </message>
</context>
<context>
    <name>VorbisMetaDataModel</name>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="56"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="57"/>
        <source>Sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="57"/>
        <source>Hz</source>
        <translation type="unfinished">Hz</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="58"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="59"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="59"/>
        <source>kbps</source>
        <translation type="unfinished">kbps</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="60"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="60"/>
        <source>KB</source>
        <translation type="unfinished">KB</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Input/vorbis/translations/vorbis_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR">
<context>
    <name>DecoderVorbisFactory</name>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="46"/>
        <source>Ogg Vorbis Plugin</source>
        <translation>Ogg Vorbis Eklentisi</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="49"/>
        <source>Ogg Vorbis Files</source>
        <translation>Ogg Vorbis Dosyaları</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="124"/>
        <source>About Ogg Vorbis Audio Plugin</source>
        <translation>Ogg Vorbis Ses Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="125"/>
        <source>Qmmp Ogg Vorbis Audio Plugin</source>
        <translation>Qmmp Ogg Vorbis Ses Eklentisi</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="126"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="127"/>
        <source>Source code based on mq3 project</source>
        <translation>Kaynak kodu mq3 projesi temellidir</translation>
    </message>
</context>
<context>
    <name>VorbisMetaDataModel</name>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="56"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="57"/>
        <source>Sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="57"/>
        <source>Hz</source>
        <translation type="unfinished">Hz</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="58"/>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="59"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="59"/>
        <source>kbps</source>
        <translation type="unfinished">kbps</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="60"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="60"/>
        <source>KB</source>
        <translation type="unfinished">KB</translation>
    </message>
</context>
</TS>
